@@ -33,7 +33,7 @@ def groups_view(request):
 
     smart_groups_qs = SmartGroup.objects.filter(
         group__in=groups_qs, auto_group=False, enabled=True
-    ).select_related("group", "group__authgroup")
+    ).select_related("group", "group__authgroup").order_by('group__name')
     graces_qs = GracePeriodRecord.objects.filter(user=request.user)
     graces = {}
     for g in graces_qs:
@@ -167,6 +167,7 @@ def smart_group_run_check(request, group_id):
 def group_manual_refresh(request, sg_id=None):
     logger.debug("group_manual_refresh called by user %s" % request.user)
     run_smart_group_update.apply_async(args=[sg_id], priority=4)
+    # think about doing notifications here
     sg = SmartGroup.objects.get(id=sg_id)
 
     messages.info(request, f"Added Priority job for '{sg.group.name}'")
